@@ -1,7 +1,7 @@
 import os
 import sys, pygame
 
-from PIL import Image
+from PIL import Image as PILImage
 import requests
 
 from .element import Element
@@ -10,7 +10,7 @@ from .sound import Sound
 from .music import Music
 
 imgUrl = "https://raw.githubusercontent.com/dehadeaaryan/pygame-builder/main/pygame-builder.png"
-img = Image.open(requests.get(imgUrl, stream=True).raw)
+img = PILImage.open(requests.get(imgUrl, stream=True).raw)
 raw = img.tobytes("raw", "RGB")
 image = pygame.image.fromstring(raw, [480, 270], "RGB")
 
@@ -24,7 +24,10 @@ class Pygame:
         self.size = self.width, self.height = size
         self.fps = fps
         self.windowCaption = windowCaption
-        self.backgroundImage = backgroundImage.getImage()
+        if backgroundImage != image:
+            self.backgroundImage = backgroundImage.getImage()
+        else:
+            self.backgroundImage = image
         self.backgroundColour = backgroundColour
 
         self.screen = pygame.display.set_mode(size)
